@@ -166,7 +166,7 @@ proc_define_selector(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *use
   if (nvars == 16) {
     grn_proc_create(ctx,
                     GRN_TEXT_VALUE(&vars[0].value), GRN_TEXT_LEN(&vars[0].value),
-                    GRN_PROC_PROCEDURE, proc_select, NULL, NULL, nvars - 1, vars + 1);
+                    GRN_PROC_COMMAND, proc_select, NULL, NULL, nvars - 1, vars + 1);
   } else {
     ERR(GRN_INVALID_ARGUMENT, "invalid argument number. %d for %d", nvars, 16);
   }
@@ -2024,6 +2024,24 @@ proc_cache_limit(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_da
   return buf;
 }
 
+static grn_obj *
+proc_register(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
+{
+  uint32_t nvars;
+  grn_expr_var *vars;
+  grn_content_type ct;
+  grn_obj *buf = args[0];
+  grn_proc_get_info(ctx, user_data, &vars, &nvars, NULL);
+  ct = (nvars >= 2) ? grn_get_ctype(&vars[1].value) : GRN_CONTENT_JSON;
+  if (GRN_TEXT_LEN(&vars[0].value)) {
+    const char *name;
+    name = GRN_TEXT_VALUE(&vars[0].value);
+    grn_db_register_by_name(ctx, name);
+  }
+  print_return_code(ctx, buf, ct);
+  return buf;
+}
+
 static grn_obj *
 func_rand(grn_ctx *ctx, int nargs, grn_obj **args, grn_user_data *user_data)
 {
@@ -2316,9 +2334,9 @@ exit :
   GRN_TEXT_INIT(&(v).value, 0);\
 }
 
-#define DEF_PROC(name, func, nvars, vars)\
+#define DEF_COMMAND(name, func, nvars, vars)\
   (grn_proc_create(ctx, (name), (sizeof(name) - 1),\
-                   GRN_PROC_PROCEDURE, (func), NULL, NULL, (nvars), (vars)))
+                   GRN_PROC_COMMAND, (func), NULL, NULL, (nvars), (vars)))
 
 void
 grn_db_init_builtin_query(grn_ctx *ctx)
@@ -2340,8 +2358,8 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[13], "drilldown_offset");
   DEF_VAR(vars[14], "drilldown_limit");
   DEF_VAR(vars[15], "output_type");
-  DEF_PROC("define_selector", proc_define_selector, 16, vars);
-  DEF_PROC("select", proc_select, 15, vars + 1);
+  DEF_COMMAND("define_selector", proc_define_selector, 16, vars);
+  DEF_COMMAND("select", proc_select, 15, vars + 1);
 
   DEF_VAR(vars[0], "values");
   DEF_VAR(vars[1], "table");
@@ -2349,17 +2367,17 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[3], "ifexists");
   DEF_VAR(vars[4], "input_type");
   DEF_VAR(vars[5], "output_type");
-  DEF_PROC("load", proc_load, 6, vars);
+  DEF_COMMAND("load", proc_load, 6, vars);
 
   DEF_VAR(vars[0], "output_type");
-  DEF_PROC("status", proc_status, 1, vars);
+  DEF_COMMAND("status", proc_status, 1, vars);
 
   DEF_VAR(vars[0], "output_type");
-  DEF_PROC("table_list", proc_table_list, 1, vars);
+  DEF_COMMAND("table_list", proc_table_list, 1, vars);
 
   DEF_VAR(vars[0], "table");
   DEF_VAR(vars[1], "output_type");
-  DEF_PROC("column_list", proc_column_list, 2, vars);
+  DEF_COMMAND("column_list", proc_column_list, 2, vars);
 
   DEF_VAR(vars[0], "name");
   DEF_VAR(vars[1], "flags");
@@ -2367,11 +2385,11 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[3], "value_type");
   DEF_VAR(vars[4], "default_tokenizer");
   DEF_VAR(vars[5], "output_type");
-  DEF_PROC("table_create", proc_table_create, 6, vars);
+  DEF_COMMAND("table_create", proc_table_create, 6, vars);
 
   DEF_VAR(vars[0], "name");
   DEF_VAR(vars[1], "output_type");
-  DEF_PROC("table_remove", proc_table_remove, 2, vars);
+  DEF_COMMAND("table_remove", proc_table_remove, 2, vars);
 
   DEF_VAR(vars[0], "table");
   DEF_VAR(vars[1], "name");
@@ -2379,41 +2397,41 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[3], "type");
   DEF_VAR(vars[4], "source");
   DEF_VAR(vars[5], "output_type");
-  DEF_PROC("column_create", proc_column_create, 6, vars);
+  DEF_COMMAND("column_create", proc_column_create, 6, vars);
 
   DEF_VAR(vars[0], "table");
   DEF_VAR(vars[1], "name");
   DEF_VAR(vars[2], "output_type");
-  DEF_PROC("column_remove", proc_column_remove, 3, vars);
+  DEF_COMMAND("column_remove", proc_column_remove, 3, vars);
 
   DEF_VAR(vars[0], "path");
   DEF_VAR(vars[1], "output_type");
-  DEF_PROC(GRN_EXPR_MISSING_NAME, proc_missing, 2, vars);
+  DEF_COMMAND(GRN_EXPR_MISSING_NAME, proc_missing, 2, vars);
 
   DEF_VAR(vars[0], "view");
   DEF_VAR(vars[1], "table");
   DEF_VAR(vars[2], "output_type");
-  DEF_PROC("view_add", proc_view_add, 3, vars);
+  DEF_COMMAND("view_add", proc_view_add, 3, vars);
 
   DEF_VAR(vars[0], "output_type");
-  DEF_PROC("quit", proc_quit, 1, vars);
-  DEF_PROC("shutdown", proc_shutdown, 1, vars);
+  DEF_COMMAND("quit", proc_quit, 1, vars);
+  DEF_COMMAND("shutdown", proc_shutdown, 1, vars);
 
   DEF_VAR(vars[0], "target_name");
   DEF_VAR(vars[1], "output_type");
-  DEF_PROC("clearlock", proc_clearlock, 2, vars);
+  DEF_COMMAND("clearlock", proc_clearlock, 2, vars);
 
   DEF_VAR(vars[0], "level");
   DEF_VAR(vars[1], "output_type");
-  DEF_PROC("log_level", proc_log_level, 2, vars);
+  DEF_COMMAND("log_level", proc_log_level, 2, vars);
 
   DEF_VAR(vars[0], "level");
   DEF_VAR(vars[1], "message");
   DEF_VAR(vars[2], "output_type");
-  DEF_PROC("log_put", proc_log_put, 3, vars);
+  DEF_COMMAND("log_put", proc_log_put, 3, vars);
 
   DEF_VAR(vars[0], "output_type");
-  DEF_PROC("log_reopen", proc_log_reopen, 1, vars);
+  DEF_COMMAND("log_reopen", proc_log_reopen, 1, vars);
 
 
   DEF_VAR(vars[0], "table");
@@ -2423,28 +2441,32 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   DEF_VAR(vars[4], "output_columns");
   DEF_VAR(vars[5], "output_type");
   DEF_VAR(vars[6], "id");
-  DEF_PROC("add", proc_add, 6, vars);
-  DEF_PROC("set", proc_set, 7, vars);
+  DEF_COMMAND("add", proc_add, 6, vars);
+  DEF_COMMAND("set", proc_set, 7, vars);
 
   DEF_VAR(vars[0], "table");
   DEF_VAR(vars[1], "key");
   DEF_VAR(vars[2], "output_columns");
   DEF_VAR(vars[3], "output_type");
   DEF_VAR(vars[4], "id");
-  DEF_PROC("get", proc_get, 5, vars);
+  DEF_COMMAND("get", proc_get, 5, vars);
 
   DEF_VAR(vars[0], "table");
   DEF_VAR(vars[1], "key");
   DEF_VAR(vars[2], "output_type");
   DEF_VAR(vars[3], "id");
-  DEF_PROC("delete", proc_delete, 4, vars);
+  DEF_COMMAND("delete", proc_delete, 4, vars);
 
   DEF_VAR(vars[0], "max");
   DEF_VAR(vars[1], "output_type");
-  DEF_PROC("cache_limit", proc_cache_limit, 2, vars);
+  DEF_COMMAND("cache_limit", proc_cache_limit, 2, vars);
 
   /* TODO: Take "output_type" argument. Do we need GRN_CONTENT_GQTP? */
-  DEF_PROC("dump", proc_dump, 0, vars);
+  DEF_COMMAND("dump", proc_dump, 0, vars);
+
+  DEF_VAR(vars[0], "path");
+  DEF_VAR(vars[1], "output_type");
+  DEF_COMMAND("register", proc_register, 2, vars);
 
   DEF_VAR(vars[0], "seed");
   grn_proc_create(ctx, "rand", 4, GRN_PROC_FUNCTION, func_rand, NULL, NULL, 0, vars);
@@ -2452,17 +2474,18 @@ grn_db_init_builtin_query(grn_ctx *ctx)
   grn_proc_create(ctx, "now", 3, GRN_PROC_FUNCTION, func_now, NULL, NULL, 0, vars);
 
   grn_proc_create(ctx, "geo_in_circle", 13, GRN_PROC_FUNCTION,
-                  func_geo_in_circle, NULL, NULL, 0, vars);
+                  func_geo_in_circle, NULL, NULL, 0, NULL);
 
   grn_proc_create(ctx, "geo_in_rectangle", 16, GRN_PROC_FUNCTION,
-                  func_geo_in_rectangle, NULL, NULL, 0, vars);
+                  func_geo_in_rectangle, NULL, NULL, 0, NULL);
 
   grn_proc_create(ctx, "geo_distance", 12, GRN_PROC_FUNCTION,
-                  func_geo_distance, NULL, NULL, 0, vars);
+                  func_geo_distance, NULL, NULL, 0, NULL);
 
   grn_proc_create(ctx, "geo_distance2", 13, GRN_PROC_FUNCTION,
-                  func_geo_distance2, NULL, NULL, 0, vars);
+                  func_geo_distance2, NULL, NULL, 0, NULL);
 
   grn_proc_create(ctx, "geo_distance3", 13, GRN_PROC_FUNCTION,
-                  func_geo_distance3, NULL, NULL, 0, vars);
+                  func_geo_distance3, NULL, NULL, 0, NULL);
+
 }
