@@ -2,6 +2,7 @@
 
 export BASE_DIR="`dirname $0`"
 top_dir="$BASE_DIR/../.."
+top_dir=$(cd $top_dir; pwd)
 
 if test x"$NO_MAKE" != x"yes"; then
     make -C $top_dir > /dev/null || exit 1
@@ -47,6 +48,9 @@ CUTTER_ARGS="$CUTTER_ARGS --exclude-directory fixtures"
 CUTTER_ARGS="$CUTTER_ARGS --exclude-directory lib"
 CUTTER_ARGS="$CUTTER_ARGS --exclude-file test-performance.so"
 
+GRN_MODULES_DIR="$top_dir/modules"
+export GRN_MODULES_DIR
+
 case `uname` in
     Darwin)
 	DYLD_LIBRARY_PATH="$top_dir/lib/.libs:$DYLD_LIBRARY_PATH"
